Re: [PATCH v2 4/4] Bump rename limit defaults (yet again)
- From
Jeff King <peff@peff.net>
- Date
- Jul 14, 2021, 20:47 UTC
- Message-ID
- <YO9NROIgMpo2zqU/@coredump.intra.peff.net>
- In-Reply-To
- <CABPp-BE=Ghkm=sZ05=A=1vC1zscbVk7qXgeEjpA5gHxsfTGAyg@mail.gmail.com>
On Wed, Jul 14, 2021 at 01:03:43PM -0700, Elijah Newren wrote:
Show 19 quoted lines
> > The 2008 timings are from the old email you linked in your commit > > message, and the new one is from running the revised script you showed. > > The savings seem like more than 30%. I don't know if that's all CPU or > > if something changed in the code. > > I was using the script you wrote in 2008, but comparing to your > reported numbers in 2011[1]. When you bumped in 2011, you said you > picked the limits of 400 & 1000 in order to give rough timings of 2s > and 10s. So the table looks more like: > > N CPU (2008) CPU (2011) c5xlarge CPU (yours) > 400 4.87s ~2s 1.106s 0.788s > 1000 27.82s ~10s 6.350s 4.431s > > So, 2011->c5xlarge on these (just recomputed now numbers) show > improvements of ~45% and ~36%. Maybe I had an outlier run earlier > that was in the upper 6s range for N=1000 and I rounded off to 30% for > the commit message? Don't know, those numbers are on a laptop that > died in the last few days.
Ah, right. I forgot about the 2011 update. So yeah, things are getting faster, but not as much as I would have hoped as somebody who came of age during the clock speed boom of the 90's. :)
Thanks for humoring my puzzlement (I don't think any of this changes the applicability of your patch).
-Peff